Node

Struct Node 

pub struct Node<T> {
    pub t: T,
    /* private fields */
}
A node in a RedBlackTree.

The only publically available field is the contained value t, which can also be obtained through val(). Node<T> implements Deref<Target = T>, so you can use &Node<T> in place of &T through deref-coercion.

Fields

t: T

The value contained in the Node.

Implementations

Source

impl<T> Node<T>

pub fn val(&self) -> &T

Returns a shared reference to the value contained in the node.

pub fn min(&self) -> &Node<T>

Returns the minimum value in this subtree.

This operation is O(log n).

pub fn max(&self) -> &Node<T>

Returns the maximum value in this subtree.

This operation is O(log n).

pub fn predecessor(&self) -> Option<&Node<T>>

Returns the predecessor node, which is the previous in-order node and is not necessarily within the sub-tree defined by the current node.

This operation is at-worst O(log n).

pub fn successor(&self) -> Option<&Node<T>>

Returns the successor node, which is the previous in-order node and is not necessarily within the sub-tree defined by the current node.

This operation is at-worst O(log n).

pub fn iter(&self) -> Iter<'_, T>

Returns an in-order iterator over shared references of the values in this sub-tree.

Iterator creation is O(1).

pub fn iter_node(&self) -> IterNode<'_, T>

Returns an in-order iterator over shared references of the nodes in this sub-tree.

Iterator creation is O(1).