pub struct Node<T> {
pub t: T,
/* private fields */
}Expand description
A node in a RedBlackTree.
The only publically available field is the contained value t, which can also be obtained through val().
Node<T> implements Deref<Target = T>, so you can use &Node<T> in place of &T through deref-coercion.
Fields
t: TThe value contained in the Node.
Implementations
Sourceimpl<T> Node<T>
impl<T> Node<T>
Sourcepub fn min(&self) -> &Node<T>
pub fn min(&self) -> &Node<T>
Returns the minimum value in this subtree.
This operation is O(log n).
Sourcepub fn max(&self) -> &Node<T>
pub fn max(&self) -> &Node<T>
Returns the maximum value in this subtree.
This operation is O(log n).
Sourcepub fn predecessor(&self) -> Option<&Node<T>>
pub fn predecessor(&self) -> Option<&Node<T>>
Returns the predecessor node, which is the previous in-order node and is not necessarily within the sub-tree defined by the current node.
This operation is at-worst O(log n).
Sourcepub fn successor(&self) -> Option<&Node<T>>
pub fn successor(&self) -> Option<&Node<T>>
Returns the successor node, which is the previous in-order node and is not necessarily within the sub-tree defined by the current node.
This operation is at-worst O(log n).